@@ -46,7 +46,6 @@ $special = array(
     'css/icinga.css',
     'css/icinga.min.css',
     'js/icinga.dev.js',
-    'js/icinga.ie8.js',
     'js/icinga.min.js'
 );
 
@@ -70,10 +69,6 @@ if (in_array($path, $special)) {
             JavaScript::sendMinified();
             break;
 
-        case 'js/icinga.ie8.js':
-            JavaScript::sendForIe8();
-            break;
-
         default:
             return false;
     }
