@@ -139,7 +139,20 @@ class Auth
         $this->getResponse()->setReloadCss(true);
         $user->setPreferences($preferences);
         $groups = $user->getGroups();
+        $userBackendName = $user->getAdditional('backend_name');
         foreach (Config::app('groups') as $name => $config) {
+            $groupsUserBackend = $config->user_backend;
+            if ($groupsUserBackend
+                && $groupsUserBackend !== 'none'
+                && $userBackendName !== null
+                && $groupsUserBackend !== $userBackendName
+            ) {
+                // Do not ask for Group membership if a specific User Backend
+                // has been assigned to that Group Backend, and the user has
+                // been authenticated by another User Backend
+                continue;
+            }
+
             try {
                 $groupBackend = UserGroupBackend::create($name, $config);
                 $groupsFromBackend = $groupBackend->getMemberships($user);
@@ -153,9 +166,20 @@ class Auth
                 continue;
             }
             if (empty($groupsFromBackend)) {
+                Logger::debug(
+                    'No groups found in backend "%s" which the user "%s" is a member of.',
+                    $name,
+                    $user->getUsername()
+                );
                 continue;
             }
             $groupsFromBackend = array_values($groupsFromBackend);
+            Logger::debug(
+                'Groups found in backend "%s" for user "%s": %s',
+                $name,
+                $user->getUsername(),
+                join(', ', $groupsFromBackend)
+            );
             $groups = array_merge($groups, array_combine($groupsFromBackend, $groupsFromBackend));
         }
         $user->setGroups($groups);
@@ -232,6 +256,23 @@ class Auth
         return $this->user;
     }
 
+    /**
+     * Set the authenticated user
+     *
+     * Note that this method just sets the authenticated user and thus bypasses our default authentication process in
+     * {@link setAuthenticated()}.
+     *
+     * @param User $user
+     *
+     * @return $this
+     */
+    public function setUser(User $user)
+    {
+        $this->user = $user;
+
+        return $this;
+    }
+
     /**
      * Try to authenticate the user with the current session
      *
