@@ -4,7 +4,6 @@
 namespace Icinga\Authentication\User;
 
 use Exception;
-use Icinga\Authentication\PasswordHelper;
 use Icinga\Data\Inspectable;
 use Icinga\Data\Inspection;
 use Icinga\Data\Filter\Filter;
@@ -117,7 +116,7 @@ class DbUserBackend extends DbRepository implements UserBackendInterface, Inspec
      *
      * @return void
      */
-    public function insert($table, array $bind)
+    public function insert($table, array $bind, array $types = array())
     {
         $this->requireTable($table);
         $bind['created_at'] = date('Y-m-d H:i:s');
@@ -138,7 +137,7 @@ class DbUserBackend extends DbRepository implements UserBackendInterface, Inspec
      * @param   array   $bind
      * @param   Filter  $filter
      */
-    public function update($table, array $bind, Filter $filter = null)
+    public function update($table, array $bind, Filter $filter = null, array $types = array())
     {
         $this->requireTable($table);
         $bind['last_modified'] = date('Y-m-d H:i:s');
@@ -166,7 +165,7 @@ class DbUserBackend extends DbRepository implements UserBackendInterface, Inspec
      */
     protected function persistPassword($value)
     {
-        return PasswordHelper::hash($value);
+        return password_hash($value, PASSWORD_DEFAULT);
     }
 
     /**
@@ -185,10 +184,17 @@ class DbUserBackend extends DbRepository implements UserBackendInterface, Inspec
             $columns = array('password_hash');
         }
 
+        $nameColumn = 'name';
+        if ($this->ds->getDbType() === 'mysql') {
+            $username = strtolower($username);
+            $nameColumn = 'BINARY LOWER(name)';
+        }
+
         $query = $this->ds->select()
             ->from($this->prependTablePrefix('user'), $columns)
-            ->where('name', $username)
+            ->where($nameColumn, $username)
             ->where('active', true);
+
         $statement = $this->ds->getDbAdapter()->prepare($query->getSelectQuery());
         $statement->execute();
         $statement->bindColumn(1, $lob, PDO::PARAM_LOB);
@@ -213,7 +219,7 @@ class DbUserBackend extends DbRepository implements UserBackendInterface, Inspec
     public function authenticate(User $user, $password)
     {
         try {
-            return PasswordHelper::verify(
+            return password_verify(
                 $password,
                 $this->getPasswordHash($user->getUsername())
             );
