@@ -3,15 +3,19 @@
 
 namespace Icinga\File;
 
+use Traversable;
+
 class Csv
 {
     protected $query;
 
-    protected function __construct() {}
-
-    public static function fromQuery($query)
+    protected function __construct()
     {
-        $csv = new Csv();
+    }
+
+    public static function fromQuery(Traversable $query)
+    {
+        $csv = new static();
         $csv->query = $query;
         return $csv;
     }
@@ -26,7 +30,7 @@ class Csv
     {
         $first = true;
         $csv = '';
-        foreach ($this->query->fetchAll() as $row) {
+        foreach ($this->query as $row) {
             if ($first) {
                 $csv .= implode(',', array_keys((array) $row)) . "\r\n";
                 $first = false;
