@@ -1,5 +1,5 @@
 <?php
-/* Icinga Web 2 | (c) 2013-2015 Icinga Development Team | GPLv2+ */
+/* Icinga Web 2 | (c) 2013 Icinga Development Team | GPLv2+ */
 
 namespace Icinga\Web\Hook;
 
@@ -10,4 +10,6 @@ use Icinga\Application\Hook\GrapherHook as BaseHook;
  *
  * Please implement hooks in Icinga\Application\Hook
  */
-abstract class GrapherHook extends BaseHook {}
+abstract class GrapherHook extends BaseHook
+{
+}
