@@ -28,7 +28,6 @@ class JavaScript
         'js/icinga/behavior/collapsible.js',
         'js/icinga/behavior/detach.js',
         'js/icinga/behavior/sparkline.js',
-        'js/icinga/behavior/tristate.js',
         'js/icinga/behavior/dropdown.js',
         'js/icinga/behavior/navigation.js',
         'js/icinga/behavior/form.js',
@@ -36,7 +35,8 @@ class JavaScript
         'js/icinga/behavior/flyover.js',
         'js/icinga/behavior/expandable.js',
         'js/icinga/behavior/filtereditor.js',
-        'js/icinga/behavior/selectable.js'
+        'js/icinga/behavior/selectable.js',
+        'js/icinga/behavior/modal.js'
     );
 
     protected static $vendorFiles = array(
@@ -77,6 +77,7 @@ class JavaScript
             $jsFiles[] = $basedir . '/' . $file;
         }
 
+        $sharedFiles = [];
         foreach (Icinga::app()->getModuleManager()->getLoadedModules() as $name => $module) {
             if ($module->hasJs()) {
                 foreach ($module->getJsFiles() as $path) {
@@ -85,8 +86,16 @@ class JavaScript
                     }
                 }
             }
+
+            if ($module->requiresJs()) {
+                foreach ($module->getJsRequires() as $path) {
+                    $sharedFiles[] = $path;
+                }
+            }
         }
-        $files = array_merge($vendorFiles, $jsFiles);
+
+        $sharedFiles = array_unique($sharedFiles);
+        $files = array_merge($vendorFiles, $jsFiles, $sharedFiles);
 
         $request = Icinga::app()->getRequest();
         $noCache = $request->getHeader('Cache-Control') === 'no-cache' || $request->getHeader('Pragma') === 'no-cache';
@@ -117,6 +126,14 @@ class JavaScript
             $js .= file_get_contents($file) . "\n\n\n";
         }
 
+        foreach ($sharedFiles as $file) {
+            if (substr($file, -7, 7) === '.min.js') {
+                $out .= ';' . ltrim(trim(file_get_contents($file)), ';') . "\n";
+            } else {
+                $js .= file_get_contents($file) . "\n\n\n";
+            }
+        }
+
         if ($minified) {
             require_once 'JShrink/Minifier.php';
             $out .= Minifier::minify($js, array('flaggedComments' => false));
