@@ -100,7 +100,7 @@ class Url
      * @param   UrlParams|array $params     Parameters that should additionally be considered for the url
      * @param   Zend_Request    $request    A request to use instead of the default one
      *
-     * @return  Url
+     * @return  static
      */
     public static function fromRequest($params = array(), $request = null)
     {
@@ -156,7 +156,7 @@ class Url
      * @param   array           $params     An array of parameters that should additionally be considered for the url
      * @param   Zend_Request    $request    A request to use instead of the default one
      *
-     * @return  Url
+     * @return  static
      */
     public static function fromPath($url, array $params = array(), $request = null)
     {
@@ -245,7 +245,7 @@ class Url
      * @param Filter    $filter     The base filter
      * @param Filter    $optional   The optional filter
      *
-     * @return Url                  The altered URL containing the new filter
+     * @return static               The altered URL containing the new filter
      * @throws ProgrammingError
      */
     public static function urlAddFilterOptional($url, $filter, $optional)
@@ -796,7 +796,7 @@ class Url
      *
      * @param   string|array    $keyOrArrayOfKeys   A single string or an array containing parameter names
      *
-     * @return  Url
+     * @return  static
      */
     public function getUrlWithout($keyOrArrayOfKeys)
     {
@@ -819,7 +819,7 @@ class Url
      * @param string|array $param  A single string or an array containing parameter names
      * @param array        $values an optional values array
      *
-     * @return Url
+     * @return static
      */
     public function with($param, $values = null)
     {
@@ -828,6 +828,32 @@ class Url
         return $url;
     }
 
+    /**
+     * Return a copy of this url with only the given parameter(s)
+     *
+     * The argument can be either a single query parameter name or
+     * an array of parameter names to keep on on the query
+     *
+     * @param string|array $keyOrArrayOfKeys
+     *
+     * @return static
+     */
+    public function onlyWith($keyOrArrayOfKeys)
+    {
+        if (! is_array($keyOrArrayOfKeys)) {
+            $keyOrArrayOfKeys = [$keyOrArrayOfKeys];
+        }
+
+        $url = clone $this;
+        foreach ($url->getParams()->toArray(false) as $key => $_) {
+            if (! in_array($key, $keyOrArrayOfKeys, true)) {
+                $url->remove($key);
+            }
+        }
+
+        return $url;
+    }
+
     public function __clone()
     {
         $this->params = clone $this->params;
