@@ -44,6 +44,7 @@ class DowntimeController extends Controller
             'is_fixed'        => 'downtime_is_fixed',
             'is_in_effect'    => 'downtime_is_in_effect',
             'entry_time'      => 'downtime_entry_time',
+            'name'            => 'downtime_name',
             'host_state',
             'service_state',
             'host_name',
@@ -85,12 +86,14 @@ class DowntimeController extends Controller
         $this->view->stateName = $isService ? Service::getStateText($this->downtime->service_state)
             : Host::getStateText($this->downtime->host_state);
 
+        $this->view->title = $this->translate('Downtimes');
         if ($this->hasPermission('monitoring/command/downtime/delete')) {
             $form = new DeleteDowntimeCommandForm();
             $form
                 ->populate(array(
                     'downtime_id'           => $this->downtime->id,
                     'downtime_is_service'   => $isService,
+                    'downtime_name'         => $this->downtime->name,
                     'redirect'              => Url::fromPath('monitoring/list/downtimes'),
                 ))
                 ->handleRequest();
