@@ -1,6 +1,8 @@
 <?php
 /* Icinga Web 2 | (c) 2014 Icinga Development Team | GPLv2+ */
 
+use Icinga\Authentication\Auth;
+
 /** @var $this \Icinga\Application\Modules\Module */
 
 $this->providePermission(
@@ -83,6 +85,10 @@ $this->providePermission(
     'monitoring/command/send-custom-notification',
     $this->translate('Allow sending custom notifications for hosts and services')
 );
+$this->providePermission(
+    'no-monitoring/contacts',
+    $this->translate('Prohibit access to contacts and contactgroups')
+);
 
 $this->provideRestriction(
     'monitoring/filter/objects',
@@ -212,18 +218,24 @@ $section->add(N_('Hostgroups'), array(
     'url'         => 'monitoring/list/hostgroups',
     'priority'    => 60
 ));
-$section->add(N_('Contacts'), array(
-    'icon'        => 'user',
-    'description' => $this->translate('List contacts'),
-    'url'         => 'monitoring/list/contacts',
-    'priority'    => 70
-));
-$section->add(N_('Contactgroups'), array(
-    'icon'        => 'users',
-    'description' => $this->translate('List users'),
-    'url'         => 'monitoring/list/contactgroups',
-    'priority'    => 70
-));
+
+// Checking the permission here since navigation items don't support negating permissions
+$auth = Auth::getInstance();
+if ($auth->hasPermission('*') || ! $auth->hasPermission('no-monitoring/contacts')) {
+    $section->add(N_('Contacts'), array(
+        'icon'        => 'user',
+        'description' => $this->translate('List contacts'),
+        'url'         => 'monitoring/list/contacts',
+        'priority'    => 70
+    ));
+    $section->add(N_('Contactgroups'), array(
+        'icon'        => 'users',
+        'description' => $this->translate('List users'),
+        'url'         => 'monitoring/list/contactgroups',
+        'priority'    => 70
+    ));
+}
+
 $section->add(N_('Comments'), array(
     'icon'        => 'chat-empty',
     'description' => $this->translate('List comments'),
@@ -377,12 +389,12 @@ $dashboard->add(
 );
 $dashboard->add(
     N_('Acknowledged Problem Services'),
-    'monitoring/list/services?service_acknowledgement_type=2&service_problem=1&sort=service_state&limit=10',
+    'monitoring/list/services?service_acknowledgement_type!=0&service_problem=1&sort=service_state&limit=10',
     140
 );
 $dashboard->add(
     N_('Acknowledged Problem Hosts'),
-    'monitoring/list/hosts?host_acknowledgement_type=2&host_problem=1&sort=host_severity&limit=10',
+    'monitoring/list/hosts?host_acknowledgement_type!=0&host_problem=1&sort=host_severity&limit=10',
     150
 );
 
