@@ -39,6 +39,13 @@ abstract class Webserver
      */
     protected $fpmUri;
 
+    /**
+     * Enable to pass requests to FPM
+     *
+     * @var bool
+     */
+    protected $enableFpm = false;
+
     /**
      * Create instance by type name
      *
@@ -174,6 +181,30 @@ abstract class Webserver
         return $this->configDir;
     }
 
+    /**
+     * Get whether FPM is enabled
+     *
+     * @return  bool
+     */
+    public function getEnableFpm()
+    {
+        return $this->enableFpm;
+    }
+
+    /**
+     * Set FPM enabled
+     *
+     * @param   bool  $flag
+     *
+     * @return  $this
+     */
+    public function setEnableFpm($flag)
+    {
+        $this->enableFpm = (bool) $flag;
+
+        return $this;
+    }
+
     /**
      * Get the address or path where to pass requests to FPM
      *
